<h1>salary_setter_package</h1>
<p>This package contains two functions.</p>
<p>increase function: need the arguments "value" and "percentage" in order to calculate increasement.</p>
<p>decrease function: need the arguments "value" and "percentage" in order to calculate decreasement.</p>

<h2>Installation</h2>
<p>Use the package manager pip to install sallary_setter_package:</p>
<p>pip install sallary_setter_package</p>

<h2>Usage</h2>
<p>from salary_setter_package.salary_setter.setter import increase, decrease</p>

<h2>Author</h2>
<p>João Gabriel Barbosa</p>

